@@ -8,7 +8,7 @@ use File::Path qw( make_path );
 use Cwd 'abs_path';
 require 5.008001; # Supporting 5.8.1+
 
-our $VERSION = '0.001008'; # 0.1.8
+our $VERSION = '0.001009'; # 0.1.9
 $VERSION = eval $VERSION;
 
 my @accessors = qw(
@@ -408,7 +408,7 @@ sub pid_running {
     return 0 unless kill 0, $self->pid;
 
     if ( $self->scan_name ) {
-        open my $lf, "-|", "ps", "-p", $self->pid, "-o", "command="
+        open my $lf, "-|", "ps", "-w", "-w", "-p", $self->pid, "-o", "command="
             or die "Failed to get pipe to ps for scan_name.";
         while ( my $line = <$lf> ) {
             return 1 if $line =~ $self->scan_name;
